==> cdek-2.0.0.tar.gz: cdek-2.0.0/CHANGELOG.md <==
# История изменений

## [2.1.0] - 2025-11-09

### Добавлено
- Новая модель `OrderUpdateRequest` для частичного обновления заказа без повторной передачи всех полей
- Обновлённые модели ответов, предоставляющие готовый доступ к `entity` и связанным сущностям

### Исправлено
- Устранены циклические зависимости между моделями `Order`, `Package` и `Item` с помощью отложенных аннотаций
- Корректна работа с Pydantic 2, включая сериализацию дат и времени в форматах API CDEK

### Изменено
- Минимальная поддерживаемая версия Python повышена до 3.8
- Добавлена зависимость `pydantic>=2.6,<3.0`
- Улучшена сборка пакета: автоматический поиск модулей и актуализированные инструкции по публикации

## [2.0.0] - 2024-12-28

### Исправлено
- Устранён циклический импорт между `mixin/item.py` и `requests/money.py` 
- Использован стандартный Python паттерн с `from __future__ import annotations` и отложенной загрузкой импортов

### Добавлено
- Поддержка Python 3.7+
- Полная интеграция с API СДЭК версии 2.0
- Автоматическая авторизация с кэшированием токена
- Получение справочников (регионы, города, ПВЗ)
- Расчёт стоимости и сроков доставки
- Создание и управление заказами
- Получение информации о заказах
- Работа с накладными и ШК-местами
- Создание договоренностей для курьера
- Заявки на вызов курьера
- Управление webhook'ами
- Получение реестров и платежей
- Получение чеков
- Поддержка всех тарифов и услуг СДЭК

### Технические детали
- Зависимость: requests>=2.25.0
- MIT лицензия
- Поддержка всех версий Python от 3.7 до 3.12

==> cdek-2.1.1.0.2.tar.gz: cdek-2.1.1.0.2/CHANGELOG.md <==
# История изменений

## [2.1.0] - 2025-11-09

### Добавлено
- Новая модель `OrderUpdateRequest` для частичного обновления заказа без повторной передачи всех полей
- Обновлённые модели ответов, предоставляющие готовый доступ к `entity` и связанным сущностям

### Исправлено
- Устранены циклические зависимости между моделями `Order`, `Package` и `Item` с помощью отложенных аннотаций
- Корректна работа с Pydantic 2, включая сериализацию дат и времени в форматах API CDEK

### Изменено
- Минимальная поддерживаемая версия Python повышена до 3.10
- Добавлена зависимость `pydantic`
- Улучшена сборка пакета: автоматический поиск модулей и актуализированные инструкции по публикации

## [1.0.0] - 2024-12-28

### Исправлено
- Устранён циклический импорт между `mixin/item.py` и `requests/money.py` 
- Использован стандартный Python паттерн с `from __future__ import annotations` и отложенной загрузкой импортов

### Добавлено
- Поддержка Python 3.7+
- Полная интеграция с API СДЭК версии 2.0
- Автоматическая авторизация с кэшированием токена
- Получение справочников (регионы, города, ПВЗ)
- Расчёт стоимости и сроков доставки
- Создание и управление заказами
- Получение информации о заказах
- Работа с накладными и ШК-местами
- Создание договоренностей для курьера
- Заявки на вызов курьера
- Управление webhook'ами
- Получение реестров и платежей
- Получение чеков
- Поддержка всех тарифов и услуг СДЭК

### Технические детали
- Зависимость: requests>=2.25.0
- MIT лицензия
- Поддержка всех версий Python от 3.7 до 3.12
